@@ -32,3 +32,13 @@ class TestCase(unittest.TestCase):
         a = z.read_file(a_path)
         b = z.read_file(b_path)
         self.assertEqual(a, b)
+        
+    def test_alioss_with_config_file(self):
+        oss = z.OssFile()
+        a_path = "setup.py"
+        b_path = os.path.join(self.root_dir, "b.py")
+        oss.upload(key="test/setup1.py", file_path=a_path)
+        oss.download(key="test/setup1.py", file_path=b_path)
+        a = z.read_file(a_path)
+        b = z.read_file(b_path)
+        self.assertEqual(a, b)
